
'''
This file is automatically generated by setup.py, So don't edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.11.2',
    'branch_nick': '(detached',
    'revision_id': 'd9578f8f992033e3ac4766c7d520b22ab4a30215',
    'revno': 5050
}
